Module option

Module option 

Structs

IntoIter
An iterator over the value in Some variant of an Option.
Iter
An iterator over a reference to the Some variant of an Option.
IterMut
An iterator over a mutable reference to the Some variant of an Option.
OptionFlattenExperimental
The iterator produced by Option::into_flat_iter. See its documentation for more.

Enums

Option
The Option type. See the module level documentation for more.