Skip to main contentModule any
Source - TypeId
- A
TypeId represents a globally unique identifier for a type.
- Any
- A trait to emulate dynamic typing.
- type_name
- Returns the name of a type as a string slice.
- type_name_of_val
- Returns the type name of the pointed-to value as a string slice.
- try_as_dynExperimental
- Returns
Some(&U) if T can be coerced to the trait object type U. Otherwise, it returns None. - try_as_dyn_mutExperimental
- Returns
Some(&mut U) if T can be coerced to the trait object type U. Otherwise, it returns None.